#include <stdio.h>
#include <string.h>

int main (int argc, char *argv[]) {
    char buffer[1024];
    if (argc > 1 && !strcmp (argv[1], "--help")) {
	fprintf (stderr, "%s swallows an infinite amount of stdin while\n"
		 "accepting any and all command line arguments.\n"
		 "It always return OK.\n", argv[0]);
	return 0;
    }
    while (read (0, buffer, 1024) != 0);
    return 0;
}
